abacusai.document — AbacusAI documentation

# `abacusai.document`

## Module Contents

### Classes

`Document` | A document in a document store

class abacusai.document.Document(client, key=None, fileSize=None, createdAt=None, annotations={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A document in a document store

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - key (str) –

    - fileSize (int) –

    - createdAt (str) – The timestamp at which the document was created.

    - annotations (DocumentAnnotation) – the annotations for this document

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict